<?php
/**
 * A factory class for socket registries
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class LoginFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton login instance for given request instance.
	 *
	 * @param	$requestInstance	An instance of a Requestable class
	 * @return	$loginInstance		An instance of a login helper (@TODO Use actual interface name)
	 */
	public static final function createLoginObjectByRequest (Requestable $requestInstance) {
		// Get registry instance
		$registryInstance = Registry::getRegistry();

		// Do we have an instance in the registry?
		if ($registryInstance->instanceExists('login_helper')) {
			// Then use this instance
			$loginInstance = $registryInstance->getInstance('login_helper');
		} else {
			// Probe on member instance
			try {
				// Try to instance member login class
				$loginInstance = self::createObjectByConfiguredName('user_login_class');

				// Test login
				$loginInstance->testLogin($requestInstance);
			} catch (UnexpectedGuestAccountException $e) {
				// Then try guest login
				$loginInstance = self::createObjectByConfiguredName('guest_login_class');

				// Test login again
				$loginInstance->testLogin($requestInstance);
			}

			// Set the instance in registry for further use
			$registryInstance->addInstance('login_helper', $loginInstance);
		}

		// Return the instance
		return $loginInstance;
	}
}

// [EOF]
?>
